@@ -40,7 +40,7 @@
 #'   transformation to calculate positions. It is only advisable to set the
 #'   `prescale_base` argument when the data have already been log-transformed.
 #'   When using a log-transform in the scale or in
-#'   [`coord_trans()`][ggplot2::coord_trans], the default `NULL` is recommended.
+#'   [`coord_transform()`][ggplot2::coord_transform], the default `NULL` is recommended.
 #' @param negative_small A `<numeric[1]>` setting the smallest absolute value
 #'   that is marked with a tick in case the scale limits include 0 or negative
 #'   numbers.
@@ -109,9 +109,7 @@ key_manual <- function(aesthetic, value = aesthetic,
 #' @rdname key_standard
 #' @export
 key_map <- function(data, ..., .call = caller_env()) {
-  mapping <- enquos(...)
-  mapping <- Filter(Negate(quo_is_missing), mapping)
-  mapping <- new_aes(mapping, env = .call)
+  mapping <- aes(!!!enquos(...))
 
   df <- eval_aes(
     data, mapping,
